@@ -2,7 +2,7 @@
  *
  * msXpertSuite - mass spectrometry software suite
  * -----------------------------------------------
- * Copyright(C) 2009,...,2018 Filippo Rusconi
+ * Copyright (C) 2009--2020 Filippo Rusconi
  *
  * http://www.msxpertsuite.org
  *
@@ -37,6 +37,7 @@
 /////////////////////// Qt includes
 #include <QMessageBox>
 #include <QSvgGenerator>
+#include <QSpinBox>
 
 /////////////////////// QCustomPlot
 
@@ -84,6 +85,16 @@ BasePlotCompositeWidget::BasePlotCompositeWidget(QWidget *parent,
   // to setup the ui so that the widgets are known when we use them below.
   m_ui.setupUi(dynamic_cast<QWidget *>(this));
 
+  // Connect the integrate to Mz pushbutton so that we can show the MS level
+  // slider.
+
+  // connect(m_ui.msLevelSpinBox,
+  // static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged),
+  connect(m_ui.msLevelSpinBox,
+          QOverload<int>::of(&QSpinBox::valueChanged),
+          this,
+          &BasePlotCompositeWidget::msLevelValueChanged);
+
   // Construct the context menu that will be associated to the main menu push
   // button.
 
@@ -100,18 +111,22 @@ BasePlotCompositeWidget::BasePlotCompositeWidget(QWidget *parent,
   m_ui.pushPinPushButton->setShortcut(QKeySequence("Ctrl+T, P"));
   m_ui.pushPinPushButton->setToolTip("Toggle push pin status (Ctrl+T,P)");
 
-  m_ui.keepTraceCreateNewPushButton->setToolTip("Overlay new trace onto the other(s) (Ctrl+T, O)");
+  m_ui.keepTraceCreateNewPushButton->setToolTip(
+    "Overlay new trace onto the other(s) (Ctrl+T, O)");
   m_ui.keepTraceCreateNewPushButton->setShortcut(QKeySequence("Ctrl+T, O"));
 
-  m_ui.eraseTraceCreateNewPushButton->setToolTip("Replace currently selected trace(s) with new one (Ctrl+T, R)");
+  m_ui.eraseTraceCreateNewPushButton->setToolTip(
+    "Replace currently selected trace(s) with new one (Ctrl+T, R)");
   m_ui.eraseTraceCreateNewPushButton->setShortcut(QKeySequence("Ctrl+T, R"));
 
   // The red cross pixmap plot widget closing button. Clicking this button
   // triggers the signal that is trapped by the containing window that then
   // handle the destruction of the widget.
 
-  m_ui.closeCompositePlotWidgetPushButton->setShortcut(QKeySequence("Ctrl+P, C"));
-  m_ui.closeCompositePlotWidgetPushButton->setToolTip("Close the composite plot widget (Ctrl+P,C)");
+  m_ui.closeCompositePlotWidgetPushButton->setShortcut(
+    QKeySequence("Ctrl+P, C"));
+  m_ui.closeCompositePlotWidgetPushButton->setToolTip(
+    "Close the composite plot widget (Ctrl+P,C)");
   connect(
     m_ui.closeCompositePlotWidgetPushButton, &QPushButton::clicked, [this]() {
       mp_parentWnd->plotCompositeWidgetDestructionRequested(this);
@@ -493,8 +508,8 @@ BasePlotCompositeWidget::plotWidgetKeyReleaseEvent(
 
 
 void
-BasePlotCompositeWidget::plotWidgetMouseReleaseEvent([
-  [maybe_unused]] const pappso::BasePlotContext &context)
+BasePlotCompositeWidget::plotWidgetMouseReleaseEvent(
+  [[maybe_unused]] const pappso::BasePlotContext &context)
 {
   // qDebug();
 
@@ -842,12 +857,77 @@ BasePlotCompositeWidget::msFragmentationSpecChanged(
   ProcessingFlow *processing_flow_p =
     getProcessingFlowPtrForPlottable(source_plottable_p);
 
+  // Set the default ms frag spec.
+  processing_flow_p->setDefaultMsFragmentationSpec(ms_fragmentation_spec);
+
+  qDebug() << "Now setting the MS level to the spin box.";
+
+  // Change the MS level value in the spinbox.
+  // But we need to disconnect the spin box' value changed signal, because
+  // otherwise, the msLevelValueChanged() is called and it will update the ms
+  // frag spec's ms level again.
+
+  disconnect(m_ui.msLevelSpinBox,
+          QOverload<int>::of(&QSpinBox::valueChanged),
+          this,
+          &BasePlotCompositeWidget::msLevelValueChanged);
+
+  m_ui.msLevelSpinBox->setValue(ms_fragmentation_spec.getMsLevel());
+
+  // And connect back
+  connect(m_ui.msLevelSpinBox,
+          QOverload<int>::of(&QSpinBox::valueChanged),
+          this,
+          &BasePlotCompositeWidget::msLevelValueChanged);
+
+
+}
+
+
+void
+BasePlotCompositeWidget::msLevelValueChanged(int value)
+{
+  // The user has selected a new MS level value, we need to ensure that this
+  // value is record in the MsFragmentationSpec.
+
+  qDebug() << "Value: " << value;
+
+  QCPAbstractPlottable *source_plottable_p =
+    plottableToBeUsedAsIntegrationSource();
+
+  if(source_plottable_p == nullptr)
+    {
+      QMessageBox::information(
+        this,
+        "Please select *one* trace",
+        "In order to set the MS level for the next integration, the source "
+        "graph needs to be selected.",
+        QMessageBox::StandardButton::Ok,
+        QMessageBox::StandardButton::NoButton);
+
+      return;
+    }
+
+  // Next get the processing flow for that specific graph.
+
+  ProcessingFlow *processing_flow_p =
+    getProcessingFlowPtrForPlottable(source_plottable_p);
+
+  // Now get the MsFragmentationSpec out of that ProcessingFlow.
+
+  MsFragmentationSpec ms_fragmentation_spec =
+    processing_flow_p->getDefaultMsFragmentationSpec();
+
+  // Update the value of the MS level.
+
+  ms_fragmentation_spec.setMsLevel(value);
+
   // And finally set the default ms frag spec.
   processing_flow_p->setDefaultMsFragmentationSpec(ms_fragmentation_spec);
 }
 
 
-MzIntegrationParams
+pappso::MzIntegrationParams
 BasePlotCompositeWidget::getMzIntegrationParams(
   const QCPAbstractPlottable *plottable_p)
 {
@@ -861,7 +941,7 @@ BasePlotCompositeWidget::getMzIntegrationParams(
   // Now extract mz integration parameters from where they sit. That might
   // be multiple places.
 
-  MzIntegrationParams mz_integration_params;
+  pappso::MzIntegrationParams mz_integration_params;
 
   // First check if the processing flow has default mz integration params.
 
@@ -872,7 +952,7 @@ BasePlotCompositeWidget::getMzIntegrationParams(
       // Check if there is at least one step in the flow that has mz integration
       // params set.
 
-      const MzIntegrationParams *most_recent_mz_integration_params_p =
+      const pappso::MzIntegrationParams *most_recent_mz_integration_params_p =
         processing_flow.mostRecentMzIntegrationParams();
 
       if(most_recent_mz_integration_params_p == nullptr)
@@ -936,7 +1016,7 @@ BasePlotCompositeWidget::showMzIntegrationParamsDlg()
     }
 
   // Get the mz integration params for the plottable.
-  MzIntegrationParams mz_integration_params =
+  pappso::MzIntegrationParams mz_integration_params =
     getMzIntegrationParams(source_plottable_p);
 
   // qDebug().noquote() << "Found mz integration params:"
@@ -973,12 +1053,12 @@ BasePlotCompositeWidget::showMzIntegrationParamsDlg()
 
       mp_mzIntegrationParamsDlg->show();
     }
-} // namespace minexpert
+}
 
 
 void
 BasePlotCompositeWidget::mzIntegrationParamsChanged(
-  MzIntegrationParams mz_integration_params)
+  pappso::MzIntegrationParams mz_integration_params)
 {
   // qDebug();
 
