@@ -3,7 +3,7 @@
  *
  * msXpertSuite - mass spectrometry software suite
  * -----------------------------------------------
- * Copyright(C) 2009,...,2018 Filippo Rusconi
+ * Copyright (C) 2009--2020 Filippo Rusconi
  *
  * http://www.msxpertsuite.org
  *
@@ -45,14 +45,15 @@
 
 /////////////////////// pappsomspp includes
 #include <pappsomspp/widget/plotwidget/baseplotwidget.h>
+#include <pappsomspp/processing/combiners/mzintegrationparams.h>
 
 
 /////////////////////// Local includes
 #include "ui_BasePlotCompositeWidget.h"
 #include "../nongui/MsRunDataSet.hpp"
 #include "../nongui/ProcessingFlow.hpp"
-#include "../nongui/MzIntegrationParams.hpp"
 #include "../nongui/AnalysisPreferences.hpp"
+#include "MzIntegrationParamsDlg.hpp"
 
 
 namespace msxps
@@ -62,7 +63,7 @@ namespace minexpert
 
 class BasePlotWnd;
 class MsFragmentationSpecDlg;
-class MzIntegrationParamsDlg;
+//class pappso::MzIntegrationParamsDlg;
 class ProcessingFlowViewerDlg;
 
 
@@ -107,7 +108,7 @@ class BasePlotCompositeWidget : public QWidget
 
   virtual void
   msFragmentationSpecReady(const MsFragmentationSpec &ms_fragmentation_spec);
-  void setMzIntegrationParams(const MzIntegrationParams &mz_integration_params);
+  void setMzIntegrationParams(const pappso::MzIntegrationParams &mz_integration_params);
 
   public slots:
 
@@ -124,12 +125,12 @@ class BasePlotCompositeWidget : public QWidget
   virtual void plottableSelectionChanged(QCPAbstractPlottable *plottable_p,
                                          bool is_selected);
 
-  void mzIntegrationParamsChanged(MzIntegrationParams mz_integration_params);
+  void mzIntegrationParamsChanged(pappso::MzIntegrationParams mz_integration_params);
 
   virtual void newTicIntensityCalculated(double tic_intensity) const;
   virtual void resetTicIntensity();
 
-  MzIntegrationParams
+  pappso::MzIntegrationParams
   getMzIntegrationParams(const QCPAbstractPlottable *plottable_p);
   void msFragmentationSpecChanged(MsFragmentationSpec ms_fragmentation_spec);
 
@@ -192,6 +193,8 @@ class BasePlotCompositeWidget : public QWidget
 
   void setPlottingColor(QCPAbstractPlottable *plottable_p, const QColor &color);
 
+  void msLevelValueChanged(int value);
+
   signals:
 
   void plotWidgetMouseReleaseEventSignal(QMouseEvent *event);
