@@ -486,7 +486,7 @@ BasePlotWnd::setMzIntegrationParamsForAllPlotWidgets()
 {
   // qDebug();
 
-  MzIntegrationParams mz_integration_params;
+  pappso::MzIntegrationParams mz_integration_params;
 
   MzIntegrationParamsDlg *mz_integration_params_dlg_p =
     new MzIntegrationParamsDlg(this, mz_integration_params, Qt::black);
@@ -510,7 +510,7 @@ BasePlotWnd::setMzIntegrationParamsForAllPlotWidgets()
 
 void
 BasePlotWnd::mzIntegrationParamsChanged(
-  MzIntegrationParams mz_integration_params)
+  pappso::MzIntegrationParams mz_integration_params)
 {
   // We now know what are the mz integ params. We need to propagate them to all
   // the pinned-down widgets.
@@ -536,7 +536,7 @@ BasePlotWnd::mzIntegrationParamsChanged(
           // know some params like the smallest/greatest m/z bin, for example.
           // Then, we'll update it with the new params set here.
 
-          MzIntegrationParams iter_mz_integration_params =
+          pappso::MzIntegrationParams iter_mz_integration_params =
             processing_flow_p->getDefaultMzIntegrationParams();
 
           // Now modify the values according to the new settings:
@@ -555,7 +555,7 @@ BasePlotWnd::mzIntegrationParamsChanged(
           processing_flow_p->setDefaultMzIntegrationParams(
             iter_mz_integration_params);
 
-          MzIntegrationParams mz_integration_params =
+          pappso::MzIntegrationParams mz_integration_params =
             processing_flow_p->getDefaultMzIntegrationParams();
 
           // qDebug() << "Set the mz integration params to one plottable:"
@@ -872,6 +872,8 @@ BasePlotWnd::integrateToTicIntensity(
       new QualifiedMassSpectrumVectorMassDataIntegratorToTicInt(
         ms_run_data_set_csp, processing_flow, qualified_mass_spectra_sp);
 
+  mass_data_integrator_p->setMaxThreadUseCount(mp_programWindow->getMaxThreadUseCount());
+
   // Ensure the mass data integrator messages are used.
 
   connect(
