@@ -41,6 +41,7 @@
 
 
 /////////////////////// pappsomspp includes
+#include <pappsomspp/processing/combiners/mzintegrationparams.h>
 
 
 /////////////////////// Local includes
@@ -123,7 +124,7 @@ class BasePlotWnd : public QMainWindow
   void savePinnedPlotsToGraphicsFile();
 
   void setMzIntegrationParamsForAllPlotWidgets();
-  void mzIntegrationParamsChanged(MzIntegrationParams mz_integration_params);
+  void mzIntegrationParamsChanged(pappso::MzIntegrationParams mz_integration_params);
 
   void setMsFragmentationSpecForAllPlotWidgets();
   void msFragmentationSpecChanged(MsFragmentationSpec ms_fragmentation_spec);
