@@ -2,7 +2,7 @@
  *
  * msXpertSuite - mass spectrometry software suite
  * -----------------------------------------------
- * Copyright(C) 2009,...,2018 Filippo Rusconi
+ * Copyright (C) 2009--2020 Filippo Rusconi
  *
  * http://www.msxpertsuite.org
  *
@@ -432,7 +432,7 @@ BaseTracePlotCompositeWidget::applySavitzkyGolayFilter()
   // Now we need to set the parameters of the SavGol filter.
 
   // Get the mz integration params for the plottable.
-  MzIntegrationParams mz_integration_params =
+  pappso::MzIntegrationParams mz_integration_params =
     getMzIntegrationParams(source_plottable_p);
 
   pappso::SavGolParams sav_gol_params = mz_integration_params.getSavGolParams();
