@@ -3,7 +3,7 @@
  *
  * msXpertSuite - mass spectrometry software suite
  * -----------------------------------------------
- * Copyright(C) 2009,...,2018 Filippo Rusconi
+ * Copyright (C) 2009--2020 Filippo Rusconi
  *
  * http://www.msxpertsuite.org
  *
@@ -53,7 +53,7 @@
 #include "BasePlotCompositeWidget.hpp"
 #include "../nongui/MsRunDataSet.hpp"
 #include "../nongui/ProcessingFlow.hpp"
-#include "../nongui/MzIntegrationParams.hpp"
+#include <pappsomspp/processing/combiners/mzintegrationparams.h>
 
 
 namespace msxps
@@ -63,7 +63,6 @@ namespace minexpert
 
 class BaseTracePlotWnd;
 class MsFragmentationSpecDlg;
-class MzIntegrationParamsDlg;
 
 
 // The BaseTracePlotCompositeWidget class is aimed at receiving QCPGraph_s, not
