@@ -2,7 +2,7 @@
  *
  * msXpertSuite - mass spectrometry software suite
  * -----------------------------------------------
- * Copyright(C) 2009,...,2018 Filippo Rusconi
+ * Copyright (C) 2009--2020 Filippo Rusconi
  *
  * http://www.msxpertsuite.org
  *
@@ -42,6 +42,7 @@
 
 /////////////////////// pappsomspp includes
 #include <pappsomspp/widget/plotwidget/driftspectraceplotwidget.h>
+#include <pappsomspp/processing/combiners/mzintegrationparams.h>
 
 
 /////////////////////// Local includes
@@ -316,9 +317,9 @@ DriftSpecTracePlotCompositeWidget::integrationRequested(
       // This is a multi-layer work: the graph has a ProcessingFlow associated
       // to it via the m_graphProcessingFlowMap. We have gotten it above.
 
-      // Extract from it the default MzIntegrationParams:
+      // Extract from it the default pappso::MzIntegrationParams:
 
-      MzIntegrationParams mz_integration_params =
+      pappso::MzIntegrationParams mz_integration_params =
         local_processing_flow.getDefaultMzIntegrationParams();
 
       // If it is not valid, then try mz integration params from the various
@@ -351,7 +352,7 @@ DriftSpecTracePlotCompositeWidget::integrationRequested(
       // here. We need to reduce the resolution to integer resolution.
       if(m_ui.integrateToDtMzPushButton->isChecked())
         {
-          mz_integration_params.setBinningType(BinningType::NONE);
+          mz_integration_params.setBinningType(pappso::BinningType::NONE);
           mz_integration_params.setDecimalPlaces(0);
         }
 
@@ -453,7 +454,7 @@ DriftSpecTracePlotCompositeWidget::integrationRequested(
 
       processing_step_p->newSpec(ProcessingType("DT_TO_MZ"), processing_spec_p);
 
-      MzIntegrationParams mz_integration_params =
+      pappso::MzIntegrationParams mz_integration_params =
         local_processing_flow.getDefaultMzIntegrationParams();
 
       // If it is not valid, then try mz integration params from the various
