@@ -2,7 +2,7 @@
  *
  * msXpertSuite - mass spectrometry software suite
  * -----------------------------------------------
- * Copyright(C) 2009,...,2018 Filippo Rusconi
+ * Copyright (C) 2009--2020 Filippo Rusconi
  *
  * http://www.msxpertsuite.org
  *
@@ -660,7 +660,7 @@ IsoSpecDlg::loadIsoSpecStandardUserTables()
       if(match.hasMatch())
         continue;
 
-      QStringList dataStringList = line.split("\t", QString::SkipEmptyParts);
+      QStringList dataStringList = line.split("\t", Qt::SkipEmptyParts);
 
       if(dataStringList.size() <
          static_cast<int>(IsoSpecTableViewColumns::TOTAL_COLUMNS))
