@@ -2,7 +2,7 @@
  *
  * msXpertSuite - mass spectrometry software suite
  * -----------------------------------------------
- * Copyright(C) 2009,...,2018 Filippo Rusconi
+ * Copyright (C) 2009--2020 Filippo Rusconi
  *
  * http://www.msxpertsuite.org
  *
@@ -273,19 +273,6 @@ MassSpecTracePlotCompositeWidget::createMainMenu()
 
   mp_mainMenu->addAction(gaussian_fit_action_p);
 
-  // We need to connect the mainMenuPushButton to the clicked slot because that
-  // is how we will  create live the contextual menu.
-
-  disconnect(m_ui.mainMenuPushButton,
-             &QPushButton::clicked,
-             this,
-             &BaseTracePlotCompositeWidget::mainMenuPushButtonClicked);
-
-  connect(m_ui.mainMenuPushButton,
-          &QPushButton::clicked,
-          this,
-          &MassSpecTracePlotCompositeWidget::mainMenuPushButtonClicked);
-
   // qDebug() << "EXIT";
 }
 
@@ -963,9 +950,9 @@ MassSpecTracePlotCompositeWidget::integrationRequested(
       // This is a multi-layer work: the graph has a ProcessingFlow associated
       // to it via the m_graphProcessingFlowMap. We have gotten it above.
 
-      // Extract from it the default MzIntegrationParams:
+      // Extract from it the default pappso::MzIntegrationParams:
 
-      MzIntegrationParams mz_integration_params =
+      pappso::MzIntegrationParams mz_integration_params =
         local_processing_flow.getDefaultMzIntegrationParams();
 
       // If it is not valid, then try mz integration params from the various
@@ -1000,7 +987,7 @@ MassSpecTracePlotCompositeWidget::integrationRequested(
       if(m_ui.integrateToDtMzPushButton->isChecked() ||
          m_ui.integrateToRtMzPushButton->isChecked())
         {
-          mz_integration_params.setBinningType(BinningType::NONE);
+          mz_integration_params.setBinningType(pappso::BinningType::NONE);
           mz_integration_params.setDecimalPlaces(0);
         }
 
@@ -1166,7 +1153,7 @@ MassSpecTracePlotCompositeWidget::addTrace(
           // Since we are asked that an integration to a mass spectrum be
           // performed, there must be a non-nullptr mz integration pointer in
           // the step.
-          const MzIntegrationParams *mz_integration_params_p =
+          const pappso::MzIntegrationParams *mz_integration_params_p =
             processing_flow.mostRecentMzIntegrationParams();
 
           if(mz_integration_params_p == nullptr)
@@ -1175,7 +1162,7 @@ MassSpecTracePlotCompositeWidget::addTrace(
               "integration "
               "params are not available in the processing flow.");
 
-          if(mz_integration_params_p->getBinningType() == BinningType::NONE)
+          if(mz_integration_params_p->getBinningType() == pappso::BinningType::NONE)
             {
               pappso::TraceMinusCombiner trace_minus_combiner;
               pappso::TracePlusCombiner trace_plus_combiner;
@@ -1243,7 +1230,7 @@ MassSpecTracePlotCompositeWidget::addTrace(
                 }
             }
           else if(mz_integration_params_p->getBinningType() ==
-                  BinningType::ARBITRARY)
+                  pappso::BinningType::ARBITRARY)
             {
               pappso::MassSpectrumMinusCombiner mass_spectrum_minus_combiner;
               pappso::MassSpectrumPlusCombiner mass_spectrum_plus_combiner;
@@ -1257,7 +1244,7 @@ MassSpecTracePlotCompositeWidget::addTrace(
               // flow we  get as parameters. Make a copy of them as we'll need
               // to set the mz smallest and greatest values to them.
 
-              const MzIntegrationParams *mz_integration_params_p =
+              const pappso::MzIntegrationParams *mz_integration_params_p =
                 processing_flow.mostRecentMzIntegrationParams();
 
               if(mz_integration_params_p == nullptr)
@@ -1265,7 +1252,7 @@ MassSpecTracePlotCompositeWidget::addTrace(
                   "Pointer to the returned mz integration parameters cannot be "
                   "nullptr.");
 
-              MzIntegrationParams copy_mz_integration_params =
+              pappso::MzIntegrationParams copy_mz_integration_params =
                 *processing_flow.mostRecentMzIntegrationParams();
 
               // Because we are making an integration to a mass spectrum plot
