@@ -196,10 +196,10 @@ MassSpecTracePlotWnd::addTracePlot(
 
 #if 0
                 // NO BINNING
-                MzIntegrationParams mz_integration_params(
+                pappso::MzIntegrationParams mz_integration_params(
                         std::numeric_limits<double>::max(), // smallest m/z
                         std::numeric_limits<double>::min(), // greatest m/z
-                        BinningType::NONE,
+                        pappso::BinningType::NONE,
                         -1, // decimal_places
                         pappso::PrecisionFactory::getDaltonInstance(0.05),
                         false, // apply_mz_shift
@@ -208,10 +208,10 @@ MassSpecTracePlotWnd::addTracePlot(
 #endif
 #if 0
                 // ARBITRARY BINNING
-                MzIntegrationParams mz_integration_params(
+                pappso::MzIntegrationParams mz_integration_params(
                         std::numeric_limits<double>::max(),
                         std::numeric_limits<double>::min(),
-                        BinningType::ARBITRARY,
+                        pappso::BinningType::ARBITRARY,
                         -1,
                         // pappso::PrecisionFactory::getDaltonInstance(0.05),
                         pappso::PrecisionFactory::getDaltonInstance(0.1),
@@ -232,7 +232,7 @@ MassSpecTracePlotWnd::addTracePlot(
                 // integration params.
 
                 // Set aside an object for later use.
-                const MzIntegrationParams *mz_integration_params_p =
+                const pappso::MzIntegrationParams *mz_integration_params_p =
                     processing_flow.mostRecentStep()->getMzIntegrationParamsPtr();
 
                 if(mz_integration_params_p == nullptr || !mz_integration_params_p->isValid())
@@ -496,7 +496,7 @@ MassSpecTracePlotWnd::integrateToMz(
   // integration params.
 
   // Set aside an object for later use.
-  const MzIntegrationParams *mz_integration_params_p =
+  const pappso::MzIntegrationParams *mz_integration_params_p =
     processing_flow.mostRecentStep()->getMzIntegrationParamsPtr();
 
   if(mz_integration_params_p == nullptr || !mz_integration_params_p->isValid())
@@ -523,6 +523,8 @@ MassSpecTracePlotWnd::integrateToMz(
     new QualifiedMassSpectrumVectorMassDataIntegratorToMz(
       ms_run_data_set_csp, processing_flow, qualified_mass_spectra_sp);
 
+  mass_data_integrator_p->setMaxThreadUseCount(mp_programWindow->getMaxThreadUseCount());
+
   // Ensure the mass data integrator messages are used.
 
   connect(
