@@ -2,7 +2,7 @@
  *
  * msXpertSuite - mass spectrometry software suite
  * -----------------------------------------------
- * Copyright(C) 2009,...,2018 Filippo Rusconi
+ * Copyright (C) 2009--2020 Filippo Rusconi
  *
  * http://www.msxpertsuite.org
  *
@@ -1103,7 +1103,7 @@ MsRunDataSetTableViewProxyModel::filterAcceptsRow(
           // single-element list containing this string.
 
           QStringList mz_value_string_list(
-            data.split(';', QString::SkipEmptyParts));
+            data.split(';', Qt::SkipEmptyParts));
 
           if(!mz_value_string_list.isEmpty())
             {
@@ -1213,7 +1213,7 @@ MsRunDataSetTableViewProxyModel::filterAcceptsRow(
           // single-element list containing this string.
 
           QStringList cell_data_z_value_string_list(
-            cell_data.split(';', QString::SkipEmptyParts));
+            cell_data.split(';', Qt::SkipEmptyParts));
 
           if(!cell_data_z_value_string_list.isEmpty())
             {
@@ -1324,7 +1324,7 @@ MsRunDataSetTableViewProxyModel::lessThan(const QModelIndex &left,
       // single-element list containing this string.
 
       QStringList z_value_list_left(
-        leftData.toString().split(';', QString::SkipEmptyParts));
+        leftData.toString().split(';', Qt::SkipEmptyParts));
 
       // qDebug() << "left_value_string_list:" << z_value_list_left;
 
@@ -1336,7 +1336,7 @@ MsRunDataSetTableViewProxyModel::lessThan(const QModelIndex &left,
       // qDebug() << "left_value_string:" << left_value_string;
 
       QStringList z_value_list_right(
-        rightData.toString().split(';', QString::SkipEmptyParts));
+        rightData.toString().split(';', Qt::SkipEmptyParts));
 
       if(z_value_list_right.isEmpty())
         return false;
@@ -1390,7 +1390,7 @@ MsRunDataSetTableViewProxyModel::lessThan(const QModelIndex &left,
       // single-element list containing this string.
 
       QStringList mz_value_list_left(
-        leftData.toString().split(';', QString::SkipEmptyParts));
+        leftData.toString().split(';', Qt::SkipEmptyParts));
 
       // qDebug() << "left_value_string_list:" << mz_value_list_left;
 
@@ -1402,7 +1402,7 @@ MsRunDataSetTableViewProxyModel::lessThan(const QModelIndex &left,
       // qDebug() << "left_value_string:" << left_value_string;
 
       QStringList mz_value_list_right(
-        rightData.toString().split(';', QString::SkipEmptyParts));
+        rightData.toString().split(';', Qt::SkipEmptyParts));
 
       if(mz_value_list_right.isEmpty())
         return false;
