@@ -411,7 +411,7 @@ MsRunDataSetTableViewWnd::showMzIntegrationParamsDlg()
 
 void
 MsRunDataSetTableViewWnd::mzIntegrationParamsChanged(
-  MzIntegrationParams mz_integration_params)
+  pappso::MzIntegrationParams mz_integration_params)
 {
   // qDebug().noquote() << "The validated mz integration parameters:"
   //<< mz_integration_params.toString();
@@ -421,7 +421,7 @@ MsRunDataSetTableViewWnd::mzIntegrationParamsChanged(
   // ms run data set upon creation of this window.
 
   // Create a local copy of the processing flow's default mz integration params.
-  MzIntegrationParams local_mz_integration_params =
+  pappso::MzIntegrationParams local_mz_integration_params =
     m_processingFlow.getDefaultMzIntegrationParams();
 
   // Update some of the values with the params after change.
