@@ -126,6 +126,9 @@ class ProgramWindow : public QMainWindow
 
   const QString &moduleName() const;
 
+  void setMaxThreadUseCount(std::size_t count);
+  std::size_t getMaxThreadUseCount();
+
   bool openMassSpectrometryFileDlg(const QString &dir_name = QDir::homePath(),
                                    bool full_in_memory     = false);
   bool openMassSpectrometryFile(const QString &fileName    = QString(),
@@ -325,8 +328,7 @@ class ProgramWindow : public QMainWindow
       *mass_data_integrator_p);
 
   void integrateQualifiedMassSpectrumVectorToRtDtSignal(
-    QualifiedMassSpectrumVectorMassDataIntegratorToRtDt
-      *mass_data_integrator_p,
+    QualifiedMassSpectrumVectorMassDataIntegratorToRtDt *mass_data_integrator_p,
     pappso::DataKind data_kind);
 
   void integrateQualifiedMassSpectrumVectorToDtRtMzSignal(
@@ -348,6 +350,10 @@ class ProgramWindow : public QMainWindow
 
   int m_selectedMsRunIndex = -1;
 
+  // The user can limit the max number of threads to use. 0 is no limitation
+  // (all the available threads are going to be used).
+  std::size_t m_maxThreadUseCount = 0;
+
   // We need to track all the plot widgets and plottables. This tree aims at
   // storing the structure of all the plottables in all the plot widgets, in all
   // the windows, for all the ms run data sets.
@@ -364,8 +370,8 @@ class ProgramWindow : public QMainWindow
   MassSpecTracePlotWnd *mp_massSpecPlotWnd       = nullptr;
   DriftSpecTracePlotWnd *mp_driftSpecPlotWnd     = nullptr;
 
-  DriftSpecMassSpecColorMapWnd *mp_driftSpecMassSpecColorMapWnd     = nullptr;
-  TicXicChromMassSpecColorMapWnd *mp_ticXicChromMassSpecColorMapWnd = nullptr;
+  DriftSpecMassSpecColorMapWnd *mp_driftSpecMassSpecColorMapWnd       = nullptr;
+  TicXicChromMassSpecColorMapWnd *mp_ticXicChromMassSpecColorMapWnd   = nullptr;
   TicXicChromDriftSpecColorMapWnd *mp_ticXicChromDriftSpecColorMapWnd = nullptr;
 
   XicExtractionWnd *mp_xicExtractionWnd = nullptr;
@@ -398,6 +404,7 @@ class ProgramWindow : public QMainWindow
   QMenu *mp_fileMenu                = nullptr;
   QMenu *mp_windowsMenu             = nullptr;
   QMenu *mp_utilitiesMenu           = nullptr;
+  QMenu *mp_preferencesMenu           = nullptr;
   QMenu *mp_helpMenu                = nullptr;
   QAction *mp_openFullMsFileAct     = nullptr;
   QAction *mp_openStreamedMsFileAct = nullptr;
