@@ -2,7 +2,7 @@
  *
  * msXpertSuite - mass spectrometry software suite
  * -----------------------------------------------
- * Copyright(C) 2009,...,2018 Filippo Rusconi
+ * Copyright (C) 2009--2020 Filippo Rusconi
  *
  * http://www.msxpertsuite.org
  *
@@ -400,9 +400,9 @@ TicXicChromTracePlotCompositeWidget::integrationRequested(
       // This is a multi-layer work: the graph has a ProcessingFlow associated
       // to it via the m_graphProcessingFlowMap. We have gotten it above.
 
-      // Extract from it the default MzIntegrationParams:
+      // Extract from it the default pappso::MzIntegrationParams:
 
-      MzIntegrationParams mz_integration_params =
+      pappso::MzIntegrationParams mz_integration_params =
         local_processing_flow.getDefaultMzIntegrationParams();
 
       // If it is not valid, then try mz integration params from the various
@@ -412,7 +412,7 @@ TicXicChromTracePlotCompositeWidget::integrationRequested(
           // qDebug()
           //<< "The processing flow's default mz integ params are not valid.";
 
-          const MzIntegrationParams *mz_integration_params_p =
+          const pappso::MzIntegrationParams *mz_integration_params_p =
             local_processing_flow.mostRecentMzIntegrationParams();
 
           if(mz_integration_params_p != nullptr)
@@ -439,7 +439,7 @@ TicXicChromTracePlotCompositeWidget::integrationRequested(
       if(m_ui.integrateToDtMzPushButton->isChecked() ||
          m_ui.integrateToRtMzPushButton->isChecked())
         {
-          mz_integration_params.setBinningType(BinningType::NONE);
+          mz_integration_params.setBinningType(pappso::BinningType::NONE);
           mz_integration_params.setDecimalPlaces(0);
         }
 
