@@ -498,8 +498,8 @@ TicXicChromTracePlotWnd::integrateToRt(
     qualified_mass_spectra_sp,
   const ProcessingFlow &processing_flow)
 {
-  qDebug().noquote() << "Integrating to RT with processing flow:"
-                     << processing_flow.toString();
+  //qDebug().noquote() << "Integrating to RT with processing flow:"
+                     //<< processing_flow.toString();
 
   // Get the ms run data set that for the graph we are going to base the
   // integration on.
@@ -527,8 +527,8 @@ TicXicChromTracePlotWnd::integrateToRt(
   if(!qualified_mass_spectra_count)
     return;
 
-  qDebug() << "The number of remaining mass spectra:"
-           << qualified_mass_spectra_count;
+  //qDebug() << "The number of remaining mass spectra:"
+           //<< qualified_mass_spectra_count;
 
   // Now start the actual integration work.
 
@@ -538,6 +538,8 @@ TicXicChromTracePlotWnd::integrateToRt(
     new QualifiedMassSpectrumVectorMassDataIntegratorToRt(
       ms_run_data_set_csp, processing_flow, qualified_mass_spectra_sp);
 
+  mass_data_integrator_p->setMaxThreadUseCount(mp_programWindow->getMaxThreadUseCount());
+
   // Ensure the mass data integrator messages are used.
 
   connect(
