@@ -2,7 +2,7 @@
  *
  * msXpertSuite - mass spectrometry software suite
  * -----------------------------------------------
- * Copyright(C) 2009,...,2018 Filippo Rusconi
+ * Copyright (C) 2009--2020 Filippo Rusconi
  *
  * http://www.msxpertsuite.org
  *
@@ -45,11 +45,11 @@
 
 /////////////////////// pappsomspp includes
 #include <pappsomspp/massspectrum/qualifiedmassspectrum.h>
+#include <pappsomspp/processing/combiners/mzintegrationparams.h>
 
 
 /////////////////////// Local includes
 #include "MsRunDataSet.hpp"
-#include "MzIntegrationParams.hpp"
 
 
 int msRunDataSetMetaTypeId = qRegisterMetaType<msxps::minexpert::MsRunDataSet>(
@@ -218,16 +218,16 @@ MsRunDataSet::getMsRunDataSetTreeCstSPtr() const
 }
 
 
-MzIntegrationParams
+pappso::MzIntegrationParams
 MsRunDataSet::craftInitialMzIntegrationParams() const
 {
-  return MzIntegrationParams(
+  return pappso::MzIntegrationParams(
     // Absolute min m/z value of the whole data set
     m_msRunDataSetStats.m_minMz,
     // Absolute max m/z value of the whole data set
     m_msRunDataSetStats.m_maxMz,
     // Binning type
-    BinningType::ARBITRARY,
+    pappso::BinningType::ARBITRARY,
     // Decimal places
     3,
     // The size of the m/z bins in Dalton units.
