@@ -2,7 +2,7 @@
  *
  * msXpertSuite - mass spectrometry software suite
  * -----------------------------------------------
- * Copyright(C) 2009,...,2018 Filippo Rusconi
+ * Copyright (C) 2009--2020 Filippo Rusconi
  *
  * http://www.msxpertsuite.org
  *
@@ -178,7 +178,7 @@ MsRunDataSetTreeMassDataIntegratorToMz::integrateToMz()
 
   // Since we are asked that an integration to a mass spectrum be performed,
   // there must be a non-nullptr mz integration pointer in the step.
-  const MzIntegrationParams *mz_integration_params_p =
+  const pappso::MzIntegrationParams *mz_integration_params_p =
     processing_step_p->getMzIntegrationParamsPtr();
 
   if(mz_integration_params_p == nullptr)
@@ -193,11 +193,11 @@ MsRunDataSetTreeMassDataIntegratorToMz::integrateToMz()
   emit setTaskDescriptionTextSignal(
     "Computing the combination of the appropriate mass spectra");
 
-  if(mz_integration_params_p->getBinningType() == BinningType::NONE)
+  if(mz_integration_params_p->getBinningType() == pappso::BinningType::NONE)
     {
       integrateToMzNoBinning();
     }
-  else if(mz_integration_params_p->getBinningType() == BinningType::ARBITRARY)
+  else if(mz_integration_params_p->getBinningType() == pappso::BinningType::ARBITRARY)
     {
       integrateToMzArbitraryBinning();
     }
@@ -297,7 +297,7 @@ MsRunDataSetTreeMassDataIntegratorToMz::integrateToMzNoBinning()
   // Since we are asked that an integration to a mass spectrum be performed,
   // there must be a non-nullptr mz integration pointer in the most recent step.
 
-  const MzIntegrationParams *mz_integration_params_p =
+  const pappso::MzIntegrationParams *mz_integration_params_p =
     m_processingFlow.mostRecentStep()->getMzIntegrationParamsPtr();
 
   if(mz_integration_params_p == nullptr)
@@ -533,7 +533,7 @@ MsRunDataSetTreeMassDataIntegratorToMz::integrateToMzArbitraryBinning()
   // Since we are asked that an integration to a mass spectrum be performed,
   // there must be a non-nullptr mz integration pointer in the most recent step.
 
-  const MzIntegrationParams *mz_integration_params_p =
+  const pappso::MzIntegrationParams *mz_integration_params_p =
     m_processingFlow.mostRecentStep()->getMzIntegrationParamsPtr();
 
   if(mz_integration_params_p == nullptr)
@@ -543,7 +543,7 @@ MsRunDataSetTreeMassDataIntegratorToMz::integrateToMzArbitraryBinning()
   // to establish the bins. Create a local copy that we'll be able to modify
   // before using it.
 
-  MzIntegrationParams local_mz_integration_params = *mz_integration_params_p;
+  pappso::MzIntegrationParams local_mz_integration_params = *mz_integration_params_p;
 
   local_mz_integration_params.setSmallestMz(
     mcsp_msRunDataSet->getMsRunDataSetStats().m_minMz);
@@ -574,7 +574,7 @@ MsRunDataSetTreeMassDataIntegratorToMz::integrateToMzArbitraryBinning()
     {
       // qDebug() << "thread index:" << iter;
 
-      if(local_mz_integration_params.getBinningType() != BinningType::ARBITRARY)
+      if(local_mz_integration_params.getBinningType() != pappso::BinningType::ARBITRARY)
         qFatal("Programming error.");
 
       // We are using MassSpectrum combiner visitors because we are going to use
