@@ -50,7 +50,7 @@
 #include "ProcessingFlow.hpp"
 #include "MsRunDataSet.hpp"
 #include "BaseMsRunDataSetTreeNodeVisitor.hpp"
-#include "MzIntegrationParams.hpp"
+#include <pappsomspp/processing/combiners/mzintegrationparams.h>
 
 
 namespace msxps
