@@ -2,7 +2,7 @@
  *
  * msXpertSuite - mass spectrometry software suite
  * -----------------------------------------------
- * Copyright(C) 2009,...,2018 Filippo Rusconi
+ * Copyright (C) 2009--2020 Filippo Rusconi
  *
  * http://www.msxpertsuite.org
  *
@@ -185,13 +185,27 @@ QualifiedMassSpectrumVectorMassDataIntegrator::getMapTrace() const
 }
 
 
+void 
+QualifiedMassSpectrumVectorMassDataIntegrator::setMaxThreadUseCount(std::size_t number)
+{
+  m_maxThreadUseCount = number;
+}
+
+
+std::size_t
+QualifiedMassSpectrumVectorMassDataIntegrator::getMaxThreadUseCount()
+{
+  return m_maxThreadUseCount;
+}
+
+
 void
 QualifiedMassSpectrumVectorMassDataIntegrator::cancelOperation()
 {
   m_isOperationCancelled = true;
 
-  qDebug() << "cancellation asked, setting m_isOperationCancelled to true and "
-              "emitting cancelOperationSignal";
+  //qDebug() << "cancellation asked, setting m_isOperationCancelled to true and "
+              //"emitting cancelOperationSignal";
 
   emit cancelOperationSignal();
 }
@@ -204,6 +218,12 @@ QualifiedMassSpectrumVectorMassDataIntegrator::bestThreadCount()
   std::size_t ideal_thread_count = QThread::idealThreadCount();
   // qDebug() << "ideal_thread_count:" << ideal_thread_count;
 
+  // If the user has limited the count of usable threads, then we need to honour
+  // that limitation. Only if the limitation value is not 0 (in which case there
+  // is no limitation).
+  if(m_maxThreadUseCount != 0 && ideal_thread_count > m_maxThreadUseCount)
+    ideal_thread_count = m_maxThreadUseCount;
+
   // Depending on the number of nodes (node_count) and on the number of thread
   // available, we need to compute the right values to parallelize correctly the
   // computations. For example, if we load a single mass spectrum from an
