@@ -2,7 +2,7 @@
  *
  * msXpertSuite - mass spectrometry software suite
  * -----------------------------------------------
- * Copyright(C) 2009,...,2018 Filippo Rusconi
+ * Copyright (C) 2009--2020 Filippo Rusconi
  *
  * http://www.msxpertsuite.org
  *
@@ -97,6 +97,9 @@ class QualifiedMassSpectrumVectorMassDataIntegrator : public QObject
 
   const pappso::MapTrace &getMapTrace() const;
 
+  void setMaxThreadUseCount(std::size_t count);
+  std::size_t getMaxThreadUseCount();
+
   public slots:
 
   void cancelOperation();
@@ -132,6 +135,8 @@ class QualifiedMassSpectrumVectorMassDataIntegrator : public QObject
   MsRunDataSetCstSPtr mcsp_msRunDataSet = nullptr;
 
   ProcessingFlow m_processingFlow;
+  
+  std::size_t m_maxThreadUseCount = 0;
 
   std::pair<double, double> m_rtRange = std::pair<double, double>(
     std::numeric_limits<double>::max(), std::numeric_limits<double>::min());
