@@ -2,7 +2,7 @@
  *
  * msXpertSuite - mass spectrometry software suite
  * -----------------------------------------------
- * Copyright(C) 2009,...,2018 Filippo Rusconi
+ * Copyright (C) 2009--2020 Filippo Rusconi
  *
  * http://www.msxpertsuite.org
  *
@@ -304,7 +304,7 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDt::integrateToDt()
         {
 
           emit setStatusTextSignal(
-            QString("Consolidating TEST drift spectra from thread %1")
+            QString("Consolidating drift spectra from thread %1")
               .arg(iter));
 
           emit setProgressBarCurrentValueSignal(iter);
@@ -662,7 +662,7 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDt::integrateToDt()
         {
 
           emit setStatusTextSignal(
-            QString("Consolidating TIC chromatograms from thread %1")
+            QString("Consolidating drift spectra from thread %1")
               .arg(iter));
 
           emit setProgressBarCurrentValueSignal(iter);
