@@ -2,7 +2,7 @@
  *
  * msXpertSuite - mass spectrometry software suite
  * -----------------------------------------------
- * Copyright(C) 2009,...,2018 Filippo Rusconi
+ * Copyright (C) 2009--2020 Filippo Rusconi
  *
  * http://www.msxpertsuite.org
  *
@@ -126,12 +126,12 @@ QualifiedMassSpectrumVectorMassDataIntegratorToMz::integrateToMz()
   m_mapTrace.clear();
 
   if(m_processingFlow.getDefaultMzIntegrationParams().getBinningType() ==
-     BinningType::NONE)
+     pappso::BinningType::NONE)
     {
       integrateToMzNoBinning();
     }
   else if(m_processingFlow.getDefaultMzIntegrationParams().getBinningType() ==
-          BinningType::ARBITRARY)
+          pappso::BinningType::ARBITRARY)
     {
       integrateToMzArbitraryBinning();
     }
@@ -253,15 +253,15 @@ QualifiedMassSpectrumVectorMassDataIntegratorToMz::integrateToMzNoBinning()
       if(m_mzRange.first != std::numeric_limits<double>::max() &&
          m_mzRange.second != std::numeric_limits<double>::min())
         {
-          qDebug() << "The m_mzRange.first:" << m_mzRange.first
-                   << "and m_mzRange.second:" << m_mzRange.second;
+          //qDebug() << "The m_mzRange.first:" << m_mzRange.first
+                   //<< "and m_mzRange.second:" << m_mzRange.second;
 
           trace_plus_combiner.setFilterResampleKeepXRange(
             pappso::FilterResampleKeepXRange(m_mzRange.first,
                                              m_mzRange.second));
         }
-      else
-        qDebug() << "There is no limitation on the m/z range.";
+      //else
+        //qDebug() << "There is no limitation on the m/z range.";
 
       while(current_iterator != end_iterator)
         {
@@ -415,7 +415,7 @@ QualifiedMassSpectrumVectorMassDataIntegratorToMz::integrateToMzNoBinning()
       ++iter;
 
       emit setStatusTextSignal(
-        QString("Consolidating TEST mass spectra from thread %1").arg(iter));
+        QString("Consolidating mass spectra from thread %1").arg(iter));
 
       // qDebug() << "In the consolidating loop, iter:" << iter
       //<< "with a MapTrace of this size : "
@@ -442,7 +442,7 @@ bool
 QualifiedMassSpectrumVectorMassDataIntegratorToMz::
   integrateToMzArbitraryBinning()
 {
-  qDebug();
+  // qDebug();
 
   //  This function needs to be called by integrateToMz() that has setup all the
   //  required parameters.
@@ -455,13 +455,12 @@ QualifiedMassSpectrumVectorMassDataIntegratorToMz::
   if(!m_processingFlow.size())
     qFatal("The processing flow cannot be empty. Program aborted.");
 
-  MzIntegrationParams local_mz_integration_params =
+  pappso::MzIntegrationParams local_mz_integration_params =
     m_processingFlow.getDefaultMzIntegrationParams();
 
   if(!local_mz_integration_params.isValid())
     {
-      // qFatal("the mz integration paramas are not valid.");
-      qDebug() << "the mz integration paramas are not valid.";
+      qDebug() << "The mz integration paramas are not valid.";
 
       // If the mz integration params are not valid, then we cannot know the
       // start and end of the bins ! We need to resort to the statistical data
@@ -563,15 +562,15 @@ QualifiedMassSpectrumVectorMassDataIntegratorToMz::
          m_mzRange.second != std::numeric_limits<double>::min())
         {
 
-          qDebug() << "The m_mzRange.first:" << m_mzRange.first
-                   << "and m_mzRange.second:" << m_mzRange.second;
+          // qDebug() << "The m_mzRange.first:" << m_mzRange.first
+          //<< "and m_mzRange.second:" << m_mzRange.second;
 
           mass_spectrum_plus_combiner.setFilterResampleKeepXRange(
             pappso::FilterResampleKeepXRange(m_mzRange.first,
                                              m_mzRange.second));
         }
-      else
-        qDebug() << "There is no limitation on the m/z range.";
+      // else
+      // qDebug() << "There is no limitation on the m/z range.";
 
       // Configure the binning mass spectrum combiner.
 
@@ -749,13 +748,13 @@ QualifiedMassSpectrumVectorMassDataIntegratorToMz::
 
       emit setStatusTextSignal(message);
 
-      // qDebug() << message;
+      //qDebug() << message;
 
       mass_spectrum_plus_combiner.combine(m_mapTrace, *current_map_trace_sp);
 
       emit setProgressBarCurrentValueSignal(iter);
 
-      // qDebug() << "Emitted current value:" << iter;
+      //qDebug() << "Emitted current value:" << iter;
     }
 
   // Write the data to file so that we can check. It works !!!
