@@ -2,7 +2,7 @@
 
 #include <QDebug>
 
-#include "../../src/nongui/MzIntegrationParams.hpp"
+#include <pappsomspp/processing/combiners/mzintegrationparams.h>
 #include <pappsomspp/utils.h>
 
 
